Cerebrum
========

Cerebrum's purpose is getting continuous data inputs from different types of perceptions as
memory sequences that triggered according to predefined threshold values and creating a complex time
based relations between those memories by Crossmodal logic  and training multiple Long Short-Term
Memory Networks with this extracted data. Lastly creating outputs triggered by a stimuli, using
pre-trained Artificial Neural Networks.
